Package: pracma
Type: Package
Version: 2.4.6
Date: 2025-10-20
Title: Practical Numerical Math Functions
Authors@R: person("Hans W.", "Borchers", 
                  email="hwborchers@googlemail.com", 
                  role=c("aut", "cre"))
Depends: R (>= 3.1.0)
Imports: graphics, grDevices, stats, utils
Suggests: NlcOptim, quadprog
Description: 
    Provides a large number of functions from numerical analysis and
    linear algebra, numerical optimization, differential equations,
    time series, plus some well-known special mathematical functions.
    Uses 'MATLAB' function names where appropriate to simplify porting.
License: GPL (>= 3)
ByteCompile: true
LazyData: yes
NeedsCompilation: no
Packaged: 2025-10-21 15:28:06 UTC; hwb
Author: Hans W. Borchers [aut, cre]
Maintainer: Hans W. Borchers <hwborchers@googlemail.com>
Repository: CRAN
Date/Publication: 2025-10-22 15:00:02 UTC
Built: R 4.4.0; ; 2026-07-18 06:31:27 UTC; unix
