Package: pracma
Type: Package
Version: 2.3.3
Date: 2021-01-22
Title: Practical Numerical Math Functions
Authors@R: person("Hans W.", "Borchers", 
                  email="hwborchers@googlemail.com", 
                  role=c("aut", "cre"))
Depends: R (>= 3.1.0)
Imports: graphics, grDevices, stats, utils
Suggests: NlcOptim, quadprog
Description: 
    Provides a large number of functions from numerical analysis and
    linear algebra, numerical optimization, differential equations,
    time series, plus some well-known special mathematical functions.
    Uses 'MATLAB' function names where appropriate to simplify porting.
License: GPL (>= 3)
ByteCompile: true
LazyData: yes
Author: Hans W. Borchers [aut, cre]
Maintainer: Hans W. Borchers <hwborchers@googlemail.com>
Repository: CRAN
Repository/R-Forge/Project: optimist
Repository/R-Forge/Revision: 495
Repository/R-Forge/DateTimeStamp: 2021-01-22 18:52:59
Date/Publication: 2021-01-23 10:10:02 UTC
NeedsCompilation: no
Packaged: 2021-01-22 19:09:06 UTC; rforge
