###
### NAMESPACE
###

## Public routines
exportPattern("^[[:alpha:]]+")

## Imports
#  importFrom("quadprog", "solve.QP")
#  importFrom("NlcOptim", "solnl")

# import("datasets")
import("graphics")
import("grDevices")
import("stats")
import("utils")

## S3 and S4 Methods
