\name{matlab}
\alias{matlab}
\title{
  Matlab Compatibility
}
\description{
  Matlab compatibility.
}
\usage{
matlab()
}
\details{
  Lists all the functions and function names that emulate Matlab functions.
}
\value{
  Invisible NULL value.
}
